boundary.jobs.shell.adapters.redis

Redis-backed job queue implementation.

Uses Redis for distributed job queuing with the following Redis data structures:

  • Sorted Sets: For scheduled jobs (scored by execute-at timestamp)
  • Lists: For priority queues (critical, high, normal, low)
  • Hashes: For job data storage
  • Sets: For tracking workers

This adapter provides production-grade job queuing with:

  • Distributed queue across multiple workers
  • Priority-based job processing
  • Scheduled job execution
  • Job persistence
  • Atomic operations
Redis-backed job queue implementation.

Uses Redis for distributed job queuing with the following Redis data structures:
- Sorted Sets: For scheduled jobs (scored by execute-at timestamp)
- Lists: For priority queues (critical, high, normal, low)
- Hashes: For job data storage
- Sets: For tracking workers

This adapter provides production-grade job queuing with:
- Distributed queue across multiple workers
- Priority-based job processing
- Scheduled job execution
- Job persistence
- Atomic operations
raw docstring

close-redis-pool!clj

(close-redis-pool! pool)

Close Redis connection pool.

Args: pool - JedisPool instance

Close Redis connection pool.

Args:
  pool - JedisPool instance
sourceraw docstring

create-redis-job-queueclj

(create-redis-job-queue pool)

Create Redis-backed job queue.

Args: pool - JedisPool instance

Returns: RedisJobQueue implementing IJobQueue

Create Redis-backed job queue.

Args:
  pool - JedisPool instance

Returns:
  RedisJobQueue implementing IJobQueue
sourceraw docstring

create-redis-job-statsclj

(create-redis-job-stats pool)

Create Redis-backed job stats.

Args: pool - JedisPool instance

Returns: RedisJobStats implementing IJobStats

Create Redis-backed job stats.

Args:
  pool - JedisPool instance

Returns:
  RedisJobStats implementing IJobStats
sourceraw docstring

create-redis-job-storeclj

(create-redis-job-store pool)

Create Redis-backed job store.

Args: pool - JedisPool instance

Returns: RedisJobStore implementing IJobStore

Create Redis-backed job store.

Args:
  pool - JedisPool instance

Returns:
  RedisJobStore implementing IJobStore
sourceraw docstring

create-redis-poolclj

(create-redis-pool config)

Create a Jedis connection pool.

Args: config - Map with: :host - Redis host (default localhost) :port - Redis port (default 6379) :password - Redis password (optional) :database - Redis database number (default 0) :max-total - Max connections (default 20) :max-idle - Max idle connections (default 10)

Returns: JedisPool instance

Create a Jedis connection pool.

Args:
  config - Map with:
           :host - Redis host (default localhost)
           :port - Redis port (default 6379)
           :password - Redis password (optional)
           :database - Redis database number (default 0)
           :max-total - Max connections (default 20)
           :max-idle - Max idle connections (default 10)

Returns:
  JedisPool instance
sourceraw docstring

heartbeat-worker!clj

(heartbeat-worker! queue worker-id)

Refresh worker heartbeat metadata. No-op for non-Redis queues.

Refresh worker heartbeat metadata.
No-op for non-Redis queues.
sourceraw docstring

register-worker!clj

(register-worker! queue worker-id queue-name)

Register worker as active and initialize heartbeat metadata. No-op for non-Redis queues.

Register worker as active and initialize heartbeat metadata.
No-op for non-Redis queues.
sourceraw docstring

unregister-worker!clj

(unregister-worker! queue worker-id)

Unregister worker from active worker set and remove metadata. No-op for non-Redis queues.

Unregister worker from active worker set and remove metadata.
No-op for non-Redis queues.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries